@@ -10,7 +10,7 @@ use IPC::Run3 qw(run3);
 
 # XXX this declaration must be on a single line
 # https://metacpan.org/pod/version#How-to-declare()-a-dotted-decimal-version
-use version; our $VERSION = version->declare('v1.0.1');
+use version; our $VERSION = version->declare('v2.0.0');
 
 sub import {
     my $class  = shift;
@@ -18,14 +18,13 @@ sub import {
 
     for my $program (@_) {
         my $sub = sub {
-            my $input = shift;
-            my $args = join ' ', @_;
-            my $maybe_args = length($args) ? " $args" : '';
-            my $command = "$program$maybe_args";
-            my $stdin = (defined($input) && length($input)) ? \$input : undef;
+            my ($input, @args) = @_;
+            my @command = ($program, @args);
+            my $command = join(' ', @command);
+            my $stdin = (defined($input) && ref($input) eq '') ? \$input : $input;
 
-            run3($command, $stdin, \my $stdout, \my $stderr, {
-                return_if_system_error => 1,
+            run3(\@command, $stdin, \my $stdout, \my $stderr, {
+                return_if_system_error => 1, # don't die on error
             });
 
             my $error = (defined($stderr) && $stderr =~ /\S/) ? ": $stderr" : '';
@@ -46,7 +45,7 @@ sub import {
         }
     }
 
-    $class->SUPER::import(SCALAR => $caller);
+    $class->SUPER::import(SCALAR => $caller, ARRAY => $caller);
 }
 
 1;
@@ -90,7 +89,7 @@ None by default.
 
 =head1 VERSION
 
-1.0.1
+2.0.0
 
 =head1 SEE ALSO
 
